@@ -16,14 +16,18 @@
 // that was distributed with this source code.
 
 use std::{
+    borrow::Cow,
     fs::{copy, create_dir_all, read_dir, DirEntry, FileType},
     io::{self, Read},
     path::{Path, PathBuf},
     time::SystemTime,
 };
 
-use crate::BasicDirEntryInfo;
 use chrono::{DateTime, Local};
+use lscolors::{LsColors, Style};
+
+use crate::interactive::SelectionCandidate;
+use crate::{BasicDirEntryInfo, PathData};
 
 pub fn timestamp_file(system_time: &SystemTime) -> String {
     let date_time: DateTime<Local> = system_time.to_owned().into();
@@ -64,6 +68,7 @@ pub fn read_stdin() -> Result<Vec<String>, Box<dyn std::error::Error + Send + Sy
 }
 
 // is this path/dir_entry something we should count as a directory for our purposes?
+#[inline(always)]
 pub fn httm_is_dir<T>(entry: &T) -> bool
 where
     T: HttmIsDir,
@@ -75,12 +80,13 @@ where
             file_type if file_type.is_file() => false,
             file_type if file_type.is_symlink() => {
                 match path.read_link() {
-                    Ok(link) => {
+                    Ok(link_target) => {
                         // First, read_link() will check symlink is pointing to a directory
                         //
                         // Next, check ancestors() against the read_link() will reduce/remove
                         // infinitely recursive paths, like /usr/bin/X11 pointing to /usr/X11
-                        link.is_dir() && link.ancestors().all(|ancestor| ancestor != link)
+                        link_target.is_dir()
+                            && path.ancestors().all(|ancestor| ancestor != link_target)
                     }
                     // we get an error? still pass the path on, as we get a good path from the dir entry
                     Err(_) => false,
@@ -98,7 +104,7 @@ pub trait HttmIsDir {
     fn get_path(&self) -> PathBuf;
 }
 
-impl HttmIsDir for PathBuf {
+impl HttmIsDir for &Path {
     fn get_filetype(&self) -> Result<FileType, std::io::Error> {
         Ok(self.metadata()?.file_type())
     }
@@ -107,6 +113,15 @@ impl HttmIsDir for PathBuf {
     }
 }
 
+impl HttmIsDir for PathData {
+    fn get_filetype(&self) -> Result<FileType, std::io::Error> {
+        Ok(self.path_buf.metadata()?.file_type())
+    }
+    fn get_path(&self) -> PathBuf {
+        self.path_buf.to_owned()
+    }
+}
+
 impl HttmIsDir for DirEntry {
     fn get_filetype(&self) -> Result<FileType, std::io::Error> {
         self.file_type()
@@ -116,7 +131,7 @@ impl HttmIsDir for DirEntry {
     }
 }
 
-impl HttmIsDir for BasicDirEntryInfo {
+impl HttmIsDir for &BasicDirEntryInfo {
     fn get_filetype(&self) -> Result<FileType, std::io::Error> {
         //  of course, this is a placeholder error, we just need an error to report back
         //  why not store the error in the struct instead?  because it's more complex.  it might
@@ -128,3 +143,50 @@ impl HttmIsDir for BasicDirEntryInfo {
         self.path.to_owned()
     }
 }
+
+#[inline(always)]
+pub fn paint_string<T>(path: T, display_name: &str) -> Cow<str>
+where
+    T: PaintString,
+{
+    if path.get_is_phantom() {
+        let style = &Style::from_ansi_sequence("38;2;250;200;200;1;0").unwrap_or_default();
+        // paint all other phantoms/deleted files the same color, light pink
+        let ansi_style = &Style::to_ansi_term_style(style);
+        Cow::Owned(ansi_style.paint(display_name).to_string())
+    } else if let Some(style) = path.get_ansi_style() {
+        let ansi_style = &Style::to_ansi_term_style(&style);
+        Cow::Owned(ansi_style.paint(display_name).to_string())
+    } else {
+        // if a non-phantom file that should not be colored (sometimes -- your regular files)
+        // or just in case if all else fails, don't paint and return string
+        Cow::Borrowed(display_name)
+    }
+}
+
+pub trait PaintString {
+    fn get_ansi_style(&self) -> Option<lscolors::style::Style>;
+    fn get_is_phantom(&self) -> bool;
+}
+
+impl PaintString for &PathData {
+    fn get_ansi_style(&self) -> Option<lscolors::style::Style> {
+        let ls_colors = LsColors::from_env().unwrap_or_default();
+        let style = ls_colors.style_for_path(self.path_buf.as_path());
+        style.map(|style| style.to_owned())
+    }
+    fn get_is_phantom(&self) -> bool {
+        self.is_phantom
+    }
+}
+
+impl PaintString for &SelectionCandidate {
+    fn get_ansi_style(&self) -> Option<lscolors::style::Style> {
+        let ls_colors = LsColors::from_env().unwrap_or_default();
+        let style = ls_colors.style_for(self);
+        style.map(|style| style.to_owned())
+    }
+    fn get_is_phantom(&self) -> bool {
+        self.is_phantom
+    }
+}
